==> haskell-nothunks-0.2.1.0-3-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-nothunks.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 nothunks
version:              0.2.1.0
visibility:           public
id:                   nothunks-0.2.1.0-A89jvhr69Nt4P39Y0SaQsn
key:                  nothunks-0.2.1.0-A89jvhr69Nt4P39Y0SaQsn
license:              Apache-2.0
copyright:            2018-2024 Input Output Global Inc (IOG)
maintainer:           Marcin Szamotulski <coot@coot.me>
author:               IOG
synopsis:             Examine values for unexpected thunks
description:
    Long lived application data typically should not contain
    any thunks. This library can be used to examine values for
    unexpected thunks, which can then be used in assertions.
    This can be invaluable in avoiding memory leaks, or tracking
    down existing ones.

category:             Development
abi:                  92b8ad1f6836545e5812cb12eb0fa32f
exposed:              True
exposed-modules:      NoThunks.Class
import-dirs:          /usr/lib/ghc-9.4.8/site-local/nothunks-0.2.1.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/nothunks-0.2.1.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/nothunks-0.2.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-nothunks
hs-libraries:         HSnothunks-0.2.1.0-A89jvhr69Nt4P39Y0SaQsn
depends:
    base-4.17.2.1 bytestring-0.11.5.3 containers-0.6.7 ghc-heap-9.4.8
    stm-2.5.1.0 text-2.0.2 time-1.12.2
    vector-0.13.2.0-3Au1UN3I5mo3WUdsg6G5fG
    wherefrom-compat-0.1.1.1-DdVlht4lykw7BKb94e5aDF

haddock-interfaces:   /usr/share/doc/haskell-nothunks/html/nothunks.haddock
haddock-html:         /usr/share/doc/haskell-nothunks/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-nothunks-0.2.1.0-4-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-nothunks.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 nothunks
version:              0.2.1.0
visibility:           public
id:                   nothunks-0.2.1.0-GafE4e6OJdi42MZppU1QJ
key:                  nothunks-0.2.1.0-GafE4e6OJdi42MZppU1QJ
license:              Apache-2.0
copyright:            2018-2024 Input Output Global Inc (IOG)
maintainer:           Marcin Szamotulski <coot@coot.me>
author:               IOG
synopsis:             Examine values for unexpected thunks
description:
    Long lived application data typically should not contain
    any thunks. This library can be used to examine values for
    unexpected thunks, which can then be used in assertions.
    This can be invaluable in avoiding memory leaks, or tracking
    down existing ones.

category:             Development
abi:                  9a5358cc29eccab494d915a1e1ce7ade
exposed:              True
exposed-modules:      NoThunks.Class
import-dirs:          /usr/lib/ghc-9.4.8/site-local/nothunks-0.2.1.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/nothunks-0.2.1.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/nothunks-0.2.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-nothunks
hs-libraries:         HSnothunks-0.2.1.0-GafE4e6OJdi42MZppU1QJ
depends:
    base-4.17.2.1 bytestring-0.11.5.3 containers-0.6.7 ghc-heap-9.4.8
    stm-2.5.1.0 text-2.0.2 time-1.12.2
    vector-0.13.2.0-89nHvRrlFmk5zBBEvFgHzR
    wherefrom-compat-0.1.1.1-DdVlht4lykw7BKb94e5aDF

haddock-interfaces:   /usr/share/doc/haskell-nothunks/html/nothunks.haddock
haddock-html:         /usr/share/doc/haskell-nothunks/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
